Documentation
¶
Overview ¶
Package lexer tokenizes MX Script source code into a stream of tokens that the parser can consume. It tracks line and column numbers so error messages can point at the exact location of a problem.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TokenType ¶
type TokenType int
const ( TokenEOF TokenType = iota TokenIllegal TokenIdent TokenNumber TokenString TokenLet TokenFn TokenReturn TokenIf TokenElse TokenLoop TokenAs TokenRoute TokenServer TokenMiddleware TokenUse TokenTry TokenCatch TokenTrue TokenFalse TokenNull TokenImport TokenExport TokenWhile TokenBreak TokenContinue TokenStatic TokenMatch TokenFatArrow TokenLBrace TokenRBrace TokenLParen TokenRParen TokenLBracket TokenRBracket TokenColon TokenComma TokenDot TokenSemicolon TokenAssign TokenEq TokenNotEq TokenLT TokenGT TokenLTEq TokenGTEq TokenPlus TokenMinus TokenStar TokenSlash TokenPercent TokenBang TokenAnd TokenOr TokenSpread TokenQuestionDot // ?. TokenNullCoalesce // ?? )
Click to show internal directories.
Click to hide internal directories.